@@ -11,6 +11,7 @@ package Kernel::Output::HTML::TicketOverview::Preview;
 
 use strict;
 use warnings;
+use utf8;
 
 use Kernel::System::VariableCheck qw(:all);
 use Kernel::Language qw(Translatable);
@@ -490,13 +491,11 @@ sub _Show {
         Data  => $StandardTemplates{Answer} || {},
     );
 
-    # customer info
-    if ( $Param{Config}->{CustomerInfo} ) {
-        if ( $Article{CustomerUserID} ) {
-            $Article{CustomerName} = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerName(
-                UserLogin => $Article{CustomerUserID},
-            );
-        }
+    # Add CustomerName
+    if ( $Article{CustomerUserID} ) {
+        $Article{CustomerName} = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerName(
+            UserLogin => $Article{CustomerUserID},
+        );
     }
 
     # get ACL restrictions
@@ -861,7 +860,6 @@ sub _Show {
         }
     }
 
-    # CustomerID and CustomerName
     if ( defined $Article{CustomerID} ) {
         $LayoutObject->Block(
             Name => 'CustomerID',
@@ -871,48 +869,41 @@ sub _Show {
             },
         );
 
-        # test access to frontend module
-        my $Access = $LayoutObject->Permission(
-            Action => 'AgentTicketCustomer',
+        my $CICRWAccess = $LayoutObject->Permission(
+            Action => 'AgentCustomerInformationCenter',
             Type   => 'rw',
         );
-        if ($Access) {
-
-            # test access to ticket
-            my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCustomer');
-            if ( $Config->{Permission} ) {
-                my $OK = $TicketObject->Permission(
-                    Type     => $Config->{Permission},
-                    TicketID => $Param{TicketID},
-                    UserID   => $Self->{UserID},
-                    LogNo    => 1,
-                );
-                if ( !$OK ) {
-                    $Access = 0;
-                }
-            }
-        }
-
-        # define proper tt block based on permissions
-        my $CustomerIDBlock = $Access ? 'CustomerIDRW' : 'CustomerIDRO';
 
         $LayoutObject->Block(
-            Name => $CustomerIDBlock,
+            Name => $CICRWAccess ? 'CustomerIDRW' : 'CustomerIDRO',
+            Data => {
+                %Param,
+                %Article,
+            },
+        );
+    }
+
+    if ( defined $Article{CustomerName} ) {
+        $LayoutObject->Block(
+            Name => 'CustomerName',
             Data => {
                 %Param,
                 %Article,
             },
         );
 
-        if ( defined $Article{CustomerName} ) {
-            $LayoutObject->Block(
-                Name => 'CustomerName',
-                Data => {
-                    %Param,
-                    %Article,
-                },
-            );
-        }
+        my $CICRWAccess = $LayoutObject->Permission(
+            Action => 'AgentCustomerUserInformationCenter',
+            Type   => 'rw',
+        );
+
+        $LayoutObject->Block(
+            Name => $CICRWAccess ? 'CustomerNameRW' : 'CustomerNameRO',
+            Data => {
+                %Param,
+                %Article,
+            },
+        );
     }
 
     # show first response time if needed
